dylib library

A set of helpers for resolving names and paths of dynamic libraries. The helpers are meant to be used in conjuction with DynamicLibrary from dart:ffi.

Properties

dylibPrefix → String
The appropriate dynamic library prefix on this platform.
no setter
dylibSuffix → String
The appropriate dynamic library suffix on this platform.
no setter

Functions

resolveDylibName(String baseName) → String
Resolves the appropriate dynamic library file name on this platform based on the specified base name.
resolveDylibPath(String baseName, {String? path, String? dartDefine, String? environmentVariable}) → String
Resolves the path to a dynamic library. The library name can be specified in a cross-platform manner as a base name.
setDylibPlatform(Platform platform) → void
Used for testing platforms.